@@ -3,7 +3,7 @@ from workbench.api.monitor import Monitor
 from workbench.api.endpoint import Endpoint
 
 # Construct a Monitor Class in one of Two Ways
-mon = Endpoint("abalone-regression-end-rt").get_monitor()
+mon = Endpoint("abalone-regression-end-rt").monitor()
 mon = Monitor("abalone-regression-end-rt")
 
 # Check the summary and details of the monitoring class
@@ -19,8 +19,3 @@ print(constraints_df.head())
 
 statistics_df = mon.get_statistics()
 print(statistics_df.head())
-
-# Get the latest data capture (inputs and outputs)
-input_df, output_df = mon.get_captured_data()
-print(input_df.head())
-print(output_df.head())
