@@ -1,5 +1,6 @@
 import IPython
 from IPython import start_ipython
+from distutils.version import LooseVersion
 from IPython.terminal.prompts import Prompts
 from IPython.terminal.ipapp import load_default_config
 from pygments.token import Token
@@ -10,7 +11,6 @@ import botocore
 import webbrowser
 import pandas as pd
 import readline  # noqa
-from distutils.version import LooseVersion
 
 try:
     import matplotlib.pyplot as plt  # noqa
@@ -34,12 +34,14 @@ from workbench.utils.repl_utils import cprint, Spinner
 from workbench.utils.workbench_logging import IMPORTANT_LEVEL_NUM, TRACE_LEVEL_NUM
 from workbench.utils.config_manager import ConfigManager
 from workbench.utils.log_utils import silence_logs, log_theme
+from workbench.api import Meta
+from workbench.cached.cached_meta import CachedMeta
 
 # If we have RDKIT/Mordred let's pull in our cheminformatics utils
 try:
     import rdkit  # noqa
     import mordred  # noqa
-    from workbench.utils import chem_utils
+    from workbench.utils.chem_utils import vis
 
     HAVE_CHEM_UTILS = True
 except ImportError:
@@ -69,7 +71,13 @@ if not ConfigManager().config_okay():
     onboard()
 
 # Set the log level to important
-# logging.getLogger("workbench").setLevel(IMPORTANT_LEVEL_NUM)
+log = logging.getLogger("workbench")
+log.setLevel(logging.INFO)
+log.addFilter(
+    lambda record: not (
+        record.getMessage().startswith("Async: Metadata") or record.getMessage().startswith("Updated Metadata")
+    )
+)
 
 
 # We want to customize our prompt colors
@@ -170,12 +178,12 @@ class WorkbenchShell:
 
         # Add cheminformatics utils if available
         if HAVE_CHEM_UTILS:
-            self.commands["show"] = chem_utils.show
+            self.commands["show"] = vis.show
 
     def start(self):
         """Start the Workbench IPython shell"""
         cprint("magenta", "\nWelcome to Workbench!")
-        if self.aws_status is False:
+        if not self.aws_status:
             cprint("red", "AWS Account Connection Failed...Review/Fix the Workbench Config:")
             cprint("red", f"Path: {self.cm.site_config_path}")
             self.show_config()
@@ -255,7 +263,7 @@ class WorkbenchShell:
 
     def import_workbench(self):
         # Import all the Workbench modules
-        spinner = self.spinner_start("Importing Workbench:")
+        spinner = self.spinner_start("Spinning up Workbench:")
         try:
             # These are the classes we want to expose to the REPL
             self.commands["DataSource"] = importlib.import_module("workbench.api.data_source").DataSource
@@ -475,8 +483,6 @@ class WorkbenchShell:
 
     # Helpers method to switch from direct Meta to Cached Meta
     def try_cached_meta(self):
-        from workbench.api import Meta
-        from workbench.cached.cached_meta import CachedMeta
 
         with silence_logs():
             self.meta = CachedMeta()
@@ -554,7 +560,7 @@ class WorkbenchShell:
         from workbench.web_interface.components.plugin_unit_test import PluginUnitTest
 
         # Get kwargs
-        theme = kwargs.get("theme", "dark")
+        theme = kwargs.get("theme", "midnight_blue")
 
         plugin_test = PluginUnitTest(plugin_class, theme=theme, input_data=data, **kwargs)
 
