@@ -3,7 +3,6 @@
 import logging
 import os
 import tempfile
-import tarfile
 import joblib
 import pickle
 import glob
@@ -26,7 +25,7 @@ from scipy.stats import spearmanr
 from sklearn.preprocessing import LabelEncoder
 
 # Workbench Imports
-from workbench.utils.model_utils import load_category_mappings_from_s3
+from workbench.utils.model_utils import load_category_mappings_from_s3, safe_extract_tarfile
 from workbench.utils.pandas_utils import convert_categorical_types
 
 # Set up the log
@@ -50,9 +49,7 @@ def xgboost_model_from_s3(model_artifact_uri: str):
         wr.s3.download(path=model_artifact_uri, local_file=local_tar_path)
 
         # Extract tarball
-        with tarfile.open(local_tar_path, "r:gz") as tar:
-            # Note: For 3.12+, can use filter="data" argument
-            tar.extractall(path=tmpdir)
+        safe_extract_tarfile(local_tar_path, tmpdir)
 
         # Define model file patterns to search for (in order of preference)
         patterns = [
@@ -285,8 +282,18 @@ def cross_fold_inference(workbench_model: Any, nfolds: int = 5) -> Tuple[Dict[st
 
     # Check if we got a full sklearn model or need to create one
     if isinstance(loaded_model, (xgb.XGBClassifier, xgb.XGBRegressor)):
-        xgb_model = loaded_model
-        is_classifier = isinstance(xgb_model, xgb.XGBClassifier)
+        is_classifier = isinstance(loaded_model, xgb.XGBClassifier)
+
+        # Get the model's hyperparameters and ensure enable_categorical=True
+        params = loaded_model.get_params()
+        params["enable_categorical"] = True
+
+        # Create new model with same params but enable_categorical=True
+        if is_classifier:
+            xgb_model = xgb.XGBClassifier(**params)
+        else:
+            xgb_model = xgb.XGBRegressor(**params)
+
     elif isinstance(loaded_model, xgb.Booster):
         # Legacy: got a booster, need to wrap it
         log.warning("Deprecated: Loaded model is a Booster, wrapping in sklearn model.")
@@ -308,10 +315,12 @@ def cross_fold_inference(workbench_model: Any, nfolds: int = 5) -> Tuple[Dict[st
     target_col = workbench_model.target()
     feature_cols = workbench_model.features()
 
-    # Convert string features to categorical
+    # Convert string[python] to object, then to category for XGBoost compatibility
+    # This avoids XGBoost's issue with pandas 2.x string[python] dtype in categorical categories
     for col in feature_cols:
-        if df[col].dtype in ["object", "string"]:
-            df[col] = df[col].astype("category")
+        if pd.api.types.is_string_dtype(df[col]):
+            # Double conversion: string[python] -> object -> category
+            df[col] = df[col].astype("object").astype("category")
 
     X = df[feature_cols]
     y = df[target_col]
@@ -440,10 +449,12 @@ def leave_one_out_inference(workbench_model: Any) -> pd.DataFrame:
     target_col = workbench_model.target()
     feature_cols = workbench_model.features()
 
-    # Convert string features to categorical
+    # Convert string[python] to object, then to category for XGBoost compatibility
+    # This avoids XGBoost's issue with pandas 2.x string[python] dtype in categorical categories
     for col in feature_cols:
-        if df[col].dtype in ["object", "string"]:
-            df[col] = df[col].astype("category")
+        if pd.api.types.is_string_dtype(df[col]):
+            # Double conversion: string[python] -> object -> category
+            df[col] = df[col].astype("object").astype("category")
 
     # Determine which samples to run LOO on
     if len(df) > 1000:
