@@ -12,7 +12,7 @@ def test():
     pprint(my_data.details())
 
     # Create a FeatureSet (with a name that has mixed case)
-    fs = my_data.to_features("aBaLone-feaTures")
+    fs = my_data.to_features("aBaLone-feaTures-Temp")
     assert fs is None
 
 
